@@ -12,6 +12,6 @@ CMSPLUGIN_SATCHMO_SETTINGS = getattr(settings, 'SATCHMO_SETTINGS', {
 	'PRODUCT_SLUG': _PRODUCT_SLUG,
 	'CATEGORY_SLUG': _CATEGORY_SLUG,
 })
-PRODUCT_URL_PATH = '%s%s/' % (getattr(CMSPLUGIN_SATCHMO_SETTINGS, 'SHOP_BASE', _SHOP_BASE), getattr(CMSPLUGIN_SATCHMO_SETTINGS, 'PRODUCT_SLUG', _PRODUCT_SLUG))
-CATEGORY_URL_PATH = '%s%s/' % (getattr(CMSPLUGIN_SATCHMO_SETTINGS, 'SHOP_BASE', _SHOP_BASE), getattr(CMSPLUGIN_SATCHMO_SETTINGS, 'CATEGORY_SLUG', _CATEGORY_SLUG))
+PRODUCT_URL_PATH = '%s%s/' % (CMSPLUGIN_SATCHMO_SETTINGS.get('SHOP_BASE', _SHOP_BASE), CMSPLUGIN_SATCHMO_SETTINGS.get('PRODUCT_SLUG', _PRODUCT_SLUG))
+CATEGORY_URL_PATH = '%s%s/' % (CMSPLUGIN_SATCHMO_SETTINGS.get('SHOP_BASE', _SHOP_BASE), CMSPLUGIN_SATCHMO_SETTINGS.get('CATEGORY_SLUG', _CATEGORY_SLUG))
 
